// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KSCREEN_VERSION_H
#define KSCREEN_VERSION_H

#define KSCREEN_VERSION_STRING "6.4.5"
#define KSCREEN_VERSION_MAJOR 6
#define KSCREEN_VERSION_MINOR 4
#define KSCREEN_VERSION_PATCH 5
#define KSCREEN_VERSION ((6<<16)|(4<<8)|(5))

#endif
